[llvm] r345836 - [X86][X86FixupLEA] Rename processInstructionForSLM to processInstructionForSlowLEA (NFCI)

Simon Pilgrim via llvm-commits llvm-commits at lists.llvm.org
Thu Nov 1 07:57:07 PDT 2018


Author: rksimon
Date: Thu Nov  1 07:57:07 2018
New Revision: 345836

URL: http://llvm.org/viewvc/llvm-project?rev=345836&view=rev
Log:
[X86][X86FixupLEA] Rename processInstructionForSLM to processInstructionForSlowLEA (NFCI)

The function isn't SLM specific (its driven by the FeatureSlowLEA flag).

Minor tidyup prior to PR38225.

Modified:
    llvm/trunk/lib/Target/X86/X86FixupLEAs.cpp

Modified: llvm/trunk/lib/Target/X86/X86FixupLEAs.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Target/X86/X86FixupLEAs.cpp?rev=345836&r1=345835&r2=345836&view=diff
==============================================================================
--- llvm/trunk/lib/Target/X86/X86FixupLEAs.cpp (original)
+++ llvm/trunk/lib/Target/X86/X86FixupLEAs.cpp Thu Nov  1 07:57:07 2018
@@ -58,10 +58,9 @@ class FixupLEAPass : public MachineFunct
                           MachineFunction::iterator MFI);
 
   /// Given a LEA instruction which is unprofitable
-  /// on Silvermont try to replace it with an equivalent ADD instruction
-  void processInstructionForSLM(MachineBasicBlock::iterator &I,
-                                MachineFunction::iterator MFI);
-
+  /// on SlowLEA targets try to replace it with an equivalent ADD instruction.
+  void processInstructionForSlowLEA(MachineBasicBlock::iterator &I,
+                                    MachineFunction::iterator MFI);
 
   /// Given a LEA instruction which is unprofitable
   /// on SNB+ try to replace it with other instructions.
@@ -411,8 +410,8 @@ void FixupLEAPass::seekLEAFixup(MachineO
   }
 }
 
-void FixupLEAPass::processInstructionForSLM(MachineBasicBlock::iterator &I,
-                                            MachineFunction::iterator MFI) {
+void FixupLEAPass::processInstructionForSlowLEA(MachineBasicBlock::iterator &I,
+                                                MachineFunction::iterator MFI) {
   MachineInstr &MI = *I;
   const int Opcode = MI.getOpcode();
   if (!isLEA(Opcode))
@@ -576,7 +575,7 @@ bool FixupLEAPass::processBasicBlock(Mac
 
     if (OptLEA) {
       if (MF.getSubtarget<X86Subtarget>().slowLEA())
-        processInstructionForSLM(I, MFI);
+        processInstructionForSlowLEA(I, MFI);
 
       else {
         if (MF.getSubtarget<X86Subtarget>().slow3OpsLEA()) {




More information about the llvm-commits mailing list